==> bacula-5.2.13-x86_64-4_slonly.txz: install/doinst.sh <==
config() {
  NEW="$1"
  OLD="$(dirname $NEW)/$(basename $NEW .new)"
  # If there's no config file by that name, mv it over:
  if [ ! -r $OLD ]; then
    mv $NEW $OLD
  elif [ "$(cat $OLD | md5sum)" = "$(cat $NEW | md5sum)" ]; then
    # toss the redundant copy
    rm $NEW
  fi
  # Otherwise, we leave the .new copy for the admin to consider...
}

preserve_perms() {
  NEW="$1"
  OLD="$(dirname $NEW)/$(basename $NEW .new)"
  if [ -e $OLD ]; then
    cp -a $OLD ${NEW}.incoming
    cat $NEW > ${NEW}.incoming
    mv ${NEW}.incoming $NEW
  fi
  config $NEW
}


preserve_perms etc/rc.d/rc.bacula.new
config etc/bacula/bacula-dir.conf.new
config etc/bacula/bacula-fd.conf.new
config etc/bacula/bacula-sd.conf.new
config etc/bacula/bconsole.conf.new
config etc/logrotate.d/bacula.new

( cd usr/lib64 ; rm -rf libbacsql.so )
( cd usr/lib64 ; ln -sf libbacsql-5.2.13.so libbacsql.so )
( cd usr/lib64 ; rm -rf libbaccats-mysql.so )
( cd usr/lib64 ; ln -sf libbaccats-mysql-5.2.13.so libbaccats-mysql.so )
( cd usr/lib64 ; rm -rf libbaccats-5.2.13.so )
( cd usr/lib64 ; ln -sf libbaccats-mysql.so libbaccats-5.2.13.so )
( cd usr/lib64 ; rm -rf libbaccfg.so )
( cd usr/lib64 ; ln -sf libbaccfg-5.2.13.so libbaccfg.so )
( cd usr/lib64 ; rm -rf libbaccats.so )
( cd usr/lib64 ; ln -sf libbaccats-5.2.13.so libbaccats.so )
( cd usr/lib64 ; rm -rf libbacpy.so )
( cd usr/lib64 ; ln -sf libbacpy-5.2.13.so libbacpy.so )
( cd usr/lib64 ; rm -rf libbac.so )
( cd usr/lib64 ; ln -sf libbac-5.2.13.so libbac.so )
( cd usr/lib64 ; rm -rf libbacfind.so )
( cd usr/lib64 ; ln -sf libbacfind-5.2.13.so libbacfind.so )

==> bacula-9.0.6-x86_64-1_slonly.txz: install/doinst.sh <==
config() {
  NEW="$1"
  OLD="$(dirname $NEW)/$(basename $NEW .new)"
  # If there's no config file by that name, mv it over:
  if [ ! -r $OLD ]; then
    mv $NEW $OLD
  elif [ "$(cat $OLD | md5sum)" = "$(cat $NEW | md5sum)" ]; then
    # toss the redundant copy
    rm $NEW
  fi
  # Otherwise, we leave the .new copy for the admin to consider...
}

preserve_perms() {
  NEW="$1"
  OLD="$(dirname $NEW)/$(basename $NEW .new)"
  if [ -e $OLD ]; then
    cp -a $OLD ${NEW}.incoming
    cat $NEW > ${NEW}.incoming
    mv ${NEW}.incoming $NEW
  fi
  config $NEW
}


preserve_perms etc/rc.d/rc.bacula.new
config etc/bacula/bacula-dir.conf.new
config etc/bacula/bacula-fd.conf.new
config etc/bacula/bacula-sd.conf.new
config etc/bacula/bconsole.conf.new
config etc/logrotate.d/bacula.new

( cd usr/lib64 ; rm -rf libbacsd.so )
( cd usr/lib64 ; ln -sf libbacsd-9.0.6.so libbacsd.so )
( cd usr/lib64 ; rm -rf libbac.so )
( cd usr/lib64 ; ln -sf libbac-9.0.6.so libbac.so )
( cd usr/lib64 ; rm -rf libbaccfg.so )
( cd usr/lib64 ; ln -sf libbaccfg-9.0.6.so libbaccfg.so )
( cd usr/lib64 ; rm -rf libbacsql.so )
( cd usr/lib64 ; ln -sf libbacsql-9.0.6.so libbacsql.so )
( cd usr/lib64 ; rm -rf libbaccats-9.0.6.so )
( cd usr/lib64 ; ln -sf libbaccats-mysql.so libbaccats-9.0.6.so )
( cd usr/lib64 ; rm -rf libbacfind.so )
( cd usr/lib64 ; ln -sf libbacfind-9.0.6.so libbacfind.so )
( cd usr/lib64 ; rm -rf libbaccats.so )
( cd usr/lib64 ; ln -sf libbaccats-9.0.6.so libbaccats.so )
( cd usr/lib64 ; rm -rf libbaccats-mysql.so )
( cd usr/lib64 ; ln -sf libbaccats-mysql-9.0.6.so libbaccats-mysql.so )
